@@ -25,14 +25,15 @@ except ImportError:
     pass
 
 dwm = windll.dwmapi
-
+SetWindowCompositionAttribute = windll.user32.SetWindowCompositionAttribute
+SetWindowCompositionAttribute()
 windll.shcore.SetProcessDpiAwareness(1)
 ScaleFactor = windll.shcore.GetScaleFactorForDevice(0)
 
 try:
     taskbar_height = GetMonitorInfo(MonitorFromPoint((0, 0))).get("Monitor")[3] - \
                      GetMonitorInfo(MonitorFromPoint((0, 0))).get("Work")[3]
-except:
+except NameError:
     pass
 Auto = "auto"
 Light = "light"
@@ -61,9 +62,10 @@ def Install_ALL(Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
     Install("win32mica", Basic=Basic, Pypi=Pypi)
     Install("BlurWindow", Basic=Basic, Pypi=Pypi)
     Install("darkdetect", Basic=Basic, Pypi=Pypi)
+    Install("tkcap", Basic=Basic, Pypi=Pypi)
 
 
-class DWMWINDOWATTRIBUTE(Enum):
+class DwmWindowAttribute(Enum):
     DWMWA_NCRENDERING_ENABLED = 1
     DWMWA_NCRENDERING_POLICY = 2
     DWMWA_TRANSITIONS_FORCEDISABLED = 3
@@ -102,12 +104,16 @@ def window_light(window: tk.Tk):
     dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), DWMWA_USE_IMMERSIVE_DARK_MODE, False)
 
 
-def window_acrylic(window: tk.Tk, Dark=False, Low: bool = False):
+def window_screenshot(window: tk.Tk, image_name: str = "Image.png"):
+    from tkcap import CAP
+    cap = CAP(window)
+    window.after(20, cap.capture(image_name))
+    return cap
+
+
+def window_acrylic(window: tk.Tk, dark=False, acrylic: bool = False, hexColor: bool = False):
     from BlurWindow.blurWindow import GlobalBlur
-    if Low:
-        GlobalBlur(GetParent(window.winfo_id()), hexColor=True, Dark=Dark, QWidget=window)
-    else:
-        GlobalBlur(GetParent(window.winfo_id()), Dark=Dark, QWidget=window)
+    GlobalBlur(GetParent(window.winfo_id()), hexColor=hexColor, Acrylic=acrylic, Dark=dark, QWidget=window)
 
 
 def window_long(window: tk.Tk, long):
@@ -668,7 +674,7 @@ try:
             super(DevToolTip, self).__init__(widget=widget, msg=msg, delay=delay, follow=follow, refresh=refresh,
                                              x_offset=x_offset, y_offset=y_offset, parent_kwargs=parent_kwargs,
                                              fg=foreground, bg=background)
-except:
+except NameError:
     pass
 
 
@@ -839,26 +845,37 @@ class DevToast(tk.Toplevel):
 class DevWindow(tk.Tk):
     def __init__(self, title: str = ""):
         super(DevWindow, self).__init__()
+        from sys import getwindowsversion
         self.title(title)
         self.geometry("630x300")
         self.iconbitmap(Icon_Empty)
+        self.configure(background="#ffffff")
+        if getwindowsversion().build >= 22621:
+            # 因为22621版本号改了标题栏，所以就改成标题栏的颜色
+            self.configure(background="#eff4f9")
 
-    def wm_acrylic(self, mode: Literal["auto", "light", "dark"] = Auto, mica: bool = True, low: bool = False):
+    def wm_screenshot(self, image="Image.png"):
+        window_screenshot(self, image)
+
+    screenshot = wm_screenshot
+
+    def wm_acrylic(self, mode: Literal["auto", "light", "dark"] = Auto,
+                   mica: bool = False, acrylic: bool = False, hexColor: bool = False):
         if mica:
             self.mica(mode)
 
         if mode == "auto":
             if darkdetect.isLight():
-                window_acrylic(self, Dark=False, Low=low)
-                self.configure(background="#d3d3d3")
+                window_acrylic(self, dark=False, acrylic=acrylic, hexColor=hexColor)
+                self.configure(background="#eff4f9")
             if darkdetect.isDark():
-                window_acrylic(self, Dark=True, Low=low)
+                window_acrylic(self, dark=True, acrylic=acrylic, hexColor=hexColor)
                 self.configure(background="#000000")
         elif mode == "light":
-            window_acrylic(self, Dark=False, Low=low)
-            self.configure(background="#d3d3d3")
+            window_acrylic(self, dark=False, acrylic=acrylic, hexColor=hexColor)
+            self.configure(background="#eff4f9")
         elif mode == "dark":
-            window_acrylic(self, Dark=True, Low=low)
+            window_acrylic(self, dark=True, acrylic=acrylic, hexColor=hexColor)
             self.configure(background="#000000")
         self.update()
 
@@ -951,5 +968,5 @@ class DevToplevel(tk.Toplevel, DevWindow):
 if __name__ == '__main__':
     Root = DevWindow()
     Root.mica()
-    Root.acrylic()
+    Root.screenshot()
     Root.run()
